==> pegasus-merchandise-api-1.3.1-sources.jar: com/thebeastshop/pegasus/merchandise/cond/PcsBrandCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;

import java.io.Serializable;
import java.util.List;

/**
 * @author Eric.Lou
 * @version $Id: PcsBrandCond.java, v 0.1 2015-07-30 10:49
 */
public class PcsBrandCond extends BaseQueryCond implements Serializable {

    public PcsBrandCond() {
        super();
    }

    /**
     * 品牌名称
     */
    private String name;

    /**
     * 国家ID
     */
    private Long countryId;

    /**
     * 国家名称
     */
    private String countryName;

    // methods

    private Integer brandStatus;
    
    private Integer type;
    
    private String operatorName;
    
    private Long categoryManager;//品类经理
    
    private Integer[] statusArr;
    
    private String sortField = "ID";
    
    private String sortType = "desc";

    private Long createUserId;

    private String channelCode;
    
    
    
	public Long getCreateUserId() {
		return createUserId;
	}

	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	public String getSortField() {
		return sortField;
	}

	public void setSortField(String sortField) {
		this.sortField = sortField;
	}

	public String getSortType() {
		return sortType;
	}

	public void setSortType(String sortType) {
		this.sortType = sortType;
	}

	public Integer[] getStatusArr() {
		return statusArr;
	}

	public void setStatusArr(Integer[] statusArr) {
		this.statusArr = statusArr;
	}

    private String categoryCode; //类目code

    private Long categoryId; //类目Id

    private List<Long> LabelIds; //标签

    private List<Long> categoryIds; //类目Ids

    private List<Long> brandIds; //品牌Ids

    private Integer isCrossBorder; //是否海淘

	public Long getCategoryManager() {
		return categoryManager;
	}

	public void setCategoryManager(Long categoryManager) {
		this.categoryManager = categoryManager;
	}


    public String getOperatorName() {
		return operatorName;
	}

	public void setOperatorName(String operatorName) {
		this.operatorName = operatorName;
	}

	public Integer getType() {
		return type;
	}

	public void setType(Integer type) {
		this.type = type;
	}

	public Integer getBrandStatus() {
		return brandStatus;
	}

	public void setBrandStatus(Integer brandStatus) {
		this.brandStatus = brandStatus;
	}

	public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Long getCountryId() {
        return countryId;
    }

    public void setCountryId(Long countryId) {
        this.countryId = countryId;
    }

    public String getCountryName() {
        return countryName;
    }

    public void setCountryName(String countryName) {
        this.countryName = countryName;
    }

    public String getCategoryCode() {
        return categoryCode;
    }

    public void setCategoryCode(String categoryCode) {
        this.categoryCode = categoryCode;
    }

    public List<Long> getLabelIds() {
        return LabelIds;
    }

    public void setLabelIds(List<Long> labelIds) {
        LabelIds = labelIds;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public List<Long> getCategoryIds() {
        return categoryIds;
    }

    public void setCategoryIds(List<Long> categoryIds) {
        this.categoryIds = categoryIds;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public List<Long> getBrandIds() {
        return brandIds;
    }

    public void setBrandIds(List<Long> brandIds) {
        this.brandIds = brandIds;
    }

    public Integer getIsCrossBorder() {
        return isCrossBorder;
    }

    public void setIsCrossBorder(Integer isCrossBorder) {
        this.isCrossBorder = isCrossBorder;
    }
}

==> pegasus-merchandise-api-1.4.11-sources.jar: com/thebeastshop/pegasus/merchandise/cond/PcsBrandCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;

import java.io.Serializable;
import java.util.List;

/**
 * @author Eric.Lou
 * @version $Id: PcsBrandCond.java, v 0.1 2015-07-30 10:49
 */
public class PcsBrandCond extends BaseQueryCond implements Serializable {

    public PcsBrandCond() {
        super();
    }

    /**
     * 品牌名称
     */
    private String name;

    /**
     * 国家ID
     */
    private Long countryId;

    /**
     * 国家名称
     */
    private String countryName;

    // methods

    private Integer brandStatus;
    
    private Integer type;
    
    private String operatorName;
    
    private Long categoryManager;//品类经理
    
    private Integer[] statusArr;
    
    private String sortField = "ID";
    
    private String sortType = "desc";

    private Long createUserId;

    private String channelCode;
    
    private String splice;
    
	public Long getCreateUserId() {
		return createUserId;
	}

	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	public String getSortField() {
		return sortField;
	}

	public void setSortField(String sortField) {
		this.sortField = sortField;
	}

	public String getSortType() {
		return sortType;
	}

	public void setSortType(String sortType) {
		this.sortType = sortType;
	}

	public Integer[] getStatusArr() {
		return statusArr;
	}

	public void setStatusArr(Integer[] statusArr) {
		this.statusArr = statusArr;
	}

    private String categoryCode; //类目code

    private Long categoryId; //类目Id

    private List<Long> LabelIds; //标签

    private List<Long> categoryIds; //类目Ids

    private List<Long> brandIds; //品牌Ids

    private Integer isCrossBorder; //是否海淘

	public Long getCategoryManager() {
		return categoryManager;
	}

	public void setCategoryManager(Long categoryManager) {
		this.categoryManager = categoryManager;
	}


    public String getOperatorName() {
		return operatorName;
	}

	public void setOperatorName(String operatorName) {
		this.operatorName = operatorName;
	}

	public Integer getType() {
		return type;
	}

	public void setType(Integer type) {
		this.type = type;
	}

	public Integer getBrandStatus() {
		return brandStatus;
	}

	public void setBrandStatus(Integer brandStatus) {
		this.brandStatus = brandStatus;
	}

	public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Long getCountryId() {
        return countryId;
    }

    public void setCountryId(Long countryId) {
        this.countryId = countryId;
    }

    public String getCountryName() {
        return countryName;
    }

    public void setCountryName(String countryName) {
        this.countryName = countryName;
    }

    public String getCategoryCode() {
        return categoryCode;
    }

    public void setCategoryCode(String categoryCode) {
        this.categoryCode = categoryCode;
    }

    public List<Long> getLabelIds() {
        return LabelIds;
    }

    public void setLabelIds(List<Long> labelIds) {
        LabelIds = labelIds;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public List<Long> getCategoryIds() {
        return categoryIds;
    }

    public void setCategoryIds(List<Long> categoryIds) {
        this.categoryIds = categoryIds;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public List<Long> getBrandIds() {
        return brandIds;
    }

    public void setBrandIds(List<Long> brandIds) {
        this.brandIds = brandIds;
    }

    public Integer getIsCrossBorder() {
        return isCrossBorder;
    }

    public void setIsCrossBorder(Integer isCrossBorder) {
        this.isCrossBorder = isCrossBorder;
    }

    public String getSplice() {
        return splice;
    }

    public void setSplice(String splice) {
        this.splice = splice;
    }
}
